@@ -1,25 +1,32 @@
-use crate::{utility::prelude::*, *};
+#![doc(hidden)]
+use crate::utility::prelude::*;
 
 const OFFSET: f64 = 7.;
 
-struct TestObj([f64; 4], [f64; 4]);
+pub struct TestObj([f64; 4], [f64; 4]);
 
 impl Default for TestObj {
     fn default() -> Self {
-        Self([0.; 4], [50.; 4])
+        Self([-50.; 4], [50.; 4])
+    }
+}
+
+impl TestObj {
+    pub fn new() -> Self {
+        Self::default()
     }
 }
 
 impl ObjFunc for TestObj {
     type Result = f64;
-    type Respond = f64;
+    type Fitness = f64;
 
-    fn fitness(&self, v: &[f64], _: &Report) -> Self::Respond {
+    fn fitness(&self, v: &[f64], _: f64) -> Self::Fitness {
         OFFSET + v[0] * v[0] + 8. * v[1] * v[1] + v[2] * v[2] + v[3] * v[3]
     }
 
     fn result(&self, v: &[f64]) -> Self::Result {
-        self.fitness(v, &Default::default())
+        self.fitness(v, 0.)
     }
 
     fn ub(&self) -> &[f64] {
@@ -30,19 +37,20 @@ impl ObjFunc for TestObj {
     }
 }
 
+#[cfg(test)]
 fn test<S>()
 where
     S: Setting + Default,
-    S::Algorithm: Algorithm<TestObj>,
+    S::Algorithm: utility::Algorithm<TestObj>,
 {
     let s = Solver::build(S::default())
-        .task(Task::MinFit(OFFSET))
+        .task(|ctx| ctx.best_f - OFFSET < 1e-20)
         .solve(TestObj::default());
     let ans = s.result();
     let x = s.best_parameters();
     let y = s.best_fitness();
-    let reports = s.reports();
-    assert!(reports.len() > 0, "{}", reports.len());
+    let report = s.report();
+    assert!(report.len() > 0, "{}", report.len());
     assert!((ans - OFFSET).abs() < 1e-20, "{}", ans);
     for i in 0..4 {
         assert!(x[i].abs() < 1e-6, "x{} = {}", i, x[i]);
@@ -57,7 +65,7 @@ fn de() {
 
 #[test]
 fn pso() {
-    test::<Pso>();
+    test::<Pso<_>>();
 }
 
 #[test]
